import store from 'src/scripts/vuex/index'
import { enumAction } from 'src/scripts/utils/enum'
import { isUndefined, isObject } from 'src/scripts/utils/types'
import fieldUtilHelper from 'src/scripts/helper/util-helper/field'
import globalUtilHelper from 'src/scripts/helper/util-helper/global'
import customerUtilHelper from 'src/scripts/helper/util-helper/customer/index'



/**
 * 获取客户详情动态视图配置 （读取客户模块字段列表生成视图配置返回。所在位置：私客弹窗的客户信息）
 * */
export function getCustomerDetailDynamicViewConfig(filterParams, action = enumAction.create) {  // filterParams: 参数对象   action: 添加或者编辑动作
  const { enumBar } = fieldUtilHelper.getBarAll()
  const { enumCategory } = fieldUtilHelper.getCategoryAll()
  const { enumType } = fieldUtilHelper.getTypeAll()
  const { enumStatus } = globalUtilHelper.getStatusAll()
  const { enumTransactionType } = customerUtilHelper.getTransactionTypeAll()

  const config = {
    mainConfig: [],
    customConfig: [],
  }
  const currentBar = enumBar.customer_detail_bar
  const fieldList = (store.getters.fieldConfig && store.getters.fieldConfig.customer) ? JSON.parse(JSON.stringify(store.getters.fieldConfig.customer)) : []
  filterParams = filterParams ? JSON.parse(JSON.stringify(filterParams)) : {}

  // 字段映射视图配置
  fieldList.map((item)=> {
    if (item.bar && item.bar.length && item.bar.indexOf(currentBar) !== -1 && item.config && item.config[currentBar]) {
      const obj = item.config[currentBar]
      // 视图配置
      const termConfig = {
        label: obj.propertyName,
        type: item.type,
        key: obj.property,
        aliasKey: obj.aliasProperty,
        keyType: null,
        canEdit: true,
        showView: true,
        required: obj.required,
        disabled: false,
        placeholder: '',
        clearable: true,
        filterable: true,
        options: [],
        dictionary: {},
        //
        weight: obj.weight,
      }
      // 选择
      if (item.type === enumType.select || item.type === enumType.multiple_select) {
        const child = item.child || []
        child.map((cItem)=> {
          if (cItem.status === enumStatus.ACTIVE) {
            termConfig.options.push({label: cItem.label, value: cItem.code, disabled: cItem.disabled})
            termConfig.dictionary[cItem.code] = cItem.label
          }
          return item
        })
        // 增加选项---使用过的选项被删除了，需要删除的选项恢复显示，但是不能选。
        if (filterParams[obj.property] && isUndefined(termConfig.dictionary[filterParams[obj.property]]) && !isUndefined(filterParams[`${obj.property}Name`])) {
          termConfig.options.push({label: filterParams[`${obj.property}Name`], value: filterParams[obj.property], disabled: true})
          termConfig.dictionary[filterParams[obj.property]] = filterParams[`${obj.property}Name`]
        }
      }
      // 配置归类
      if (item.category === enumCategory.PLATFORM || item.category === enumCategory.PLATFORM_BASE) {
        if (obj.status === enumStatus.ACTIVE) {
          config.mainConfig.push(termConfig)
        }
      } else if (item.category === enumCategory.TENANT_CUSTOM) {
        if (obj.status === enumStatus.ACTIVE) {
          config.customConfig.push(termConfig)
        }
      }
    }
    return item
  })


  // 视图配置
  if (currentBar === enumBar.customer_detail_bar) { // 客户详情配置
    config.mainConfig.map((item)=> {
      // 销售员
      if (item.key === 'belongStaffId') {
        item.staffProps = {apiType: 'permission_staff', queryParams: {authGroup: 'CUSTOMER'}, clearable: false}
        if (action === enumAction.update) {
          item.canEdit = false
        }
      }

      // 联系方式
      if (item.key === 'contactWayList') {
        item.type = 'slot'
      }

      // 类型
      if (item.key === 'belongStaffId') {
        item.type = 'staff'
      } else if (item.key === 'estateId') {
        item.type = 'estate'
        item.estateProps = {clearable: true}
      } else if (item.key === 'city') {
        item.type = 'city'
      }

      // 文本区域
      if (item.type === 'textarea') {
        item.colspan = '100%'
      }

      // 展示（字段只是展示用的）
      if (item.key === 'createDate' || item.key === 'updateDate' || item.key === 'fromCompanyDate') {
        item.canEdit = false
      }

      // 求租、求购
      if (filterParams.transactionType === enumTransactionType.RENT) { // 求租
        if (item.key === 'totalPriceBudget' || item.key === 'paymentMethod' || item.key === 'purchasePurpose') {
          item.showView = false
        } else if (item.key === 'rentBudget' || item.key === 'rentMethod') {
          item.showView = true
        }
      } else if (filterParams.transactionType !== enumTransactionType.RENT) { // 默认
        if (item.key === 'totalPriceBudget' || item.key === 'paymentMethod' || item.key === 'purchasePurpose') {
          item.showView = true
        } else if (item.key === 'rentBudget' || item.key === 'rentMethod') {
          item.showView = false
        }
      }

      return item
    })
  }

  // 排序
  config.mainConfig.sort((a, b)=> a.weight - b.weight)
  config.customConfig.sort((a, b)=> a.weight - b.weight)

  return config
}




/**
 * 给字体加入span标签
* */
export function getSpacingFont(str) {
  let text = ''
  const arr = str.split('')
  arr.map((item)=> {
    text += `<span>${item}</span>`
    return item
  })
  return text
}








/**
 * 返回---新对象
 *
 * 自定义字段数据转换（字段管理的自定义字段，接口返回的数据的自定义字段都放在extraProperty对象里，模板使用需要把extraProperty拍平）
 * */
// 视图数据转为接口数据---返回接口数据（新对象）
export function customFieldViewDataToInterfaceData(viewData, interModel) {  // viewData视图数据   interModel接口模型
  const vObj = JSON.parse(JSON.stringify(viewData))
  const iObj = JSON.parse(JSON.stringify(interModel))
  const model = {}
  const iKeys = Object.keys(iObj)
  iKeys.map((key)=> {
    model[key] = isUndefined(vObj[key]) ? null : vObj[key]
    delete vObj[key]
    return key
  })
  model.extraProperty = vObj
  return model
}
// 接口数据转为视图数据---返回视图数据（新对象）
export function customFieldInterfaceDataToViewData(interData) {
  const iObj = JSON.parse(JSON.stringify(interData))
  let model = {}
  let extraProperty = {}
  if (iObj.extraProperty) {
    extraProperty = iObj.extraProperty
    const keys = Object.keys(extraProperty)
    keys.map((key)=> {
      if (isObject(extraProperty[key])) {
        if (isUndefined(extraProperty[key].label)) {
          console.error('获取的label不存在！')
        }
        const label = extraProperty[key].label || null
        const value = extraProperty[key].value || null
        extraProperty[`${key}Name`] = label
        extraProperty[key] = value
      }
      return key
    })
    //
    delete iObj.extraProperty
  }
  model = {...iObj, ...extraProperty}
  return model
}


