import Vue from 'vue'
import { Dialog } from 'vant'
import MD5 from 'js-md5'
import axios from 'axios'
import API from 'src/scripts/service/api'
import store from 'scripts/vuex'
import router from 'src/scripts/router/index'
import checkHelper from '../helper/check-helper'

const getAuthorization = (ts)=> {
  // const authorizationCode = '123123213'
  const authorizationCode = store.getters.authorizationCode
  return MD5(`${ts}-${authorizationCode}`)
}

//设置超时时间
axios.defaults.timeout = 10000

// axios global interceptors
axios.interceptors.request.use(
  (config)=> {
    // 在请求头中加入时间戳及动态授权码
    const ts = new Date().getTime()
    //config.headers.common['x-timestamp'] = ts
    //config.headers.common['x-authorization'] = getAuthorization(ts)
    config.headers.common['license-code'] = store.getters.authorizationCode
    config.headers.common['x-client-version'] = 'nanjing-lite-app'
    config.headers.common['tenant-id'] = store.getters.tenantId
    if (config.url !== '/apiproxy/auth/login') {
      config.headers.common['x-auth-token'] = store.getters.loginToken
    }
    // if (store.getters.loginToken) {
    //   config.headers.common['x-auth-token'] = store.getters.loginToken
    // }
    return config
  },
  (error)=> {
    Promise.reject(error)
  }
)

axios.interceptors.response.use(
  (response)=> {
    if (response.config.url === '/apiproxy/auth/login') {
      // console.log('登录成功')
    } else if (response.data && response.data.code === 200) {
      // console.log('正常返回')
    } else if (response.data && response.data.code === 401 && response.config.url !== '/apiproxy/tenant/license/apply/add') {
      router.replace('/login')
    } else if (response.data && response.data.code === 403) {
      Dialog.alert({
        message: response.data.msg || response.data.data || '没有权限',
      }).then(() => {
      })
    } else if (response.data && response.data.code === 500) {
      Dialog.alert({
        message: '服务异常',
      }).then(() => {
      })
    } else {
      Dialog.alert({
        message: response.data.msg || response.data.data || response.data,
      }).then(() => {
      })
    }

    // 检查
    if (checkHelper.isOpenAuth() && !checkHelper.isAuth()) {
      if (window.location.pathname !== '/auth') {
        router.replace('/auth')
      }
      return response
    }
    if (!checkHelper.isLogin()) {
      if (window.location.pathname !== '/login' && window.location.pathname !== '/auth') {
        router.replace('/login')
      }
      return response
    }
    //
    return response
  },
  (error)=> {
    if (!error.response) {
      Dialog.alert({
        message: error,
      }).then(() => {
      })
    } else if (error.response.status === 401) {
      router.replace('/login')
      Dialog.alert({
        message: error.response.data.msg || error.response.data.data || '账号或密码错误',
      }).then(() => {
      })
    } else if (error.response.status === 500) {
      Dialog.alert({
        message: '连接超时，请检查网络是否正常!',
      }).then(() => {
      })
    } else if (error.response.status === 502) {
      Dialog.alert({
        message: '服务器错误!',
      }).then(() => {
      })
    } else if (error.response.status === 503) {
      Dialog.alert({
        message: '服务正在更新!',
      }).then(() => {
      })
    } else if (error.response.status === 504) {
      Dialog.alert({
        message: '服务器超时!',
      }).then(() => {
      })
    } else {
      Dialog.alert({
        message: error,
      }).then(() => {
      })
    }
    return Promise.reject(error)
  }
)


export default {
  install(_vue) {
    _vue.prototype.$axios = axios

    axios.get(API.getFileDomain).then((res)=> {
      if (res.data.code === 200) {
        API.fileDomain = res.data.data
      }
    })
  },
}
