import Vue from 'vue'
import VueRouter from 'vue-router'
import { Toast } from 'vant'
import store from 'scripts/vuex'
import routes from './routes'


Vue.use(VueRouter)

const router = new VueRouter({
  mode: 'history',
  routes,
})


const commit = store.commit

const history = window.localStorage
let historyCount = history.getItem('count') * 1 || 0
history.setItem('/', 0)


// router global interceptors
router.beforeEach((to, from, next) => {
  commit('routerHistory', {to: to.path, from: from.path})
  const toIndex = history.getItem(to.path)
  const fromIndex = history.getItem(from.path)
  let animate = ''
  if (toIndex) {
    if (toIndex > fromIndex) {
      commit('pageDirection', 'forward')
      animate = 'animate-slide-right'
    } else {
      commit('pageDirection', 'reverse')
      animate = 'animate-slide-left'
    }
  } else {
    historyCount += 1
    history.setItem('count', historyCount)
    if (to.path !== '/') {
      history.setItem(to.path, historyCount)
    }
    commit('pageDirection', 'forward')
    animate = 'animate-slide-right'
  }
  router.app.routerAnimate = animate

  Toast.loading({
    message: '加载中...',
    forbidClick: true,
  })
  next()
})
router.afterEach((to, from)=> {
  Toast.clear()
  // // 离开页面清空分享记录
  // if (/micromessenger/i.test(navigator.userAgent) && Helper.appReady) Helper.wxClearShareInfo()
})

// 处理路由重复报错显示
const originalPush = VueRouter.prototype.push
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch(err => err)
}


export default router
