import Vue from 'vue'
import qs from 'qs'
import Api from './api'

/**
 * 客户列表
* */
function getCustomerList(params) {
  return Vue.prototype.$axios.get(Api.customerList, {params})
}

/**
 * 添加或编辑客户
 * */
function createOrUpdateCustomer(params) {
  return Vue.prototype.$axios.post(Api.customer, params)
}


/**
 * 客户详情
 * */
function getCustomerDetail(customerId) {
  return Vue.prototype.$axios.get(`${Api.customer}/${customerId}`)
}

/**
 * 客户事件列表
* */
function getCustomerEventList(customerId, params) {
  return Vue.prototype.$axios.get(Api.getCustomerEventList(customerId), {params})
}


/**
 * 添加共享客户
 * */
function createShareCustomer(customerId, params) {
  return Vue.prototype.$axios.post(Api.getCreateShareCustomer(customerId), qs.stringify(params))
}

/**
 * 解绑共享客户
 * */
function deleteShareCustomer(customerId, params) {
  return Vue.prototype.$axios.delete(Api.getDeleteShareCustomer(customerId), {params})
}

/**
 * 添加回访记录
 * */
function createCustomerRevisit(params) {
  return Vue.prototype.$axios.post(Api.customerRevisit, params)
}

/**
 * 删除回访记录
 * */
function deleteCustomerRevisit(id) {
  return Vue.prototype.$axios.delete(`${Api.customerRevisit}/${id}`)
}

/**
 * 添加带看记录
 * */
function createCustomerGuideVisit(params) {
  return Vue.prototype.$axios.post(Api.customerGuideVisit, params)
}

/**
 * 删除带看记录
 * */
function deleteCustomerGuideVisit(id) {
  return Vue.prototype.$axios.delete(`${Api.customerGuideVisit}/${id}`)
}

/**
 * 添加客户行程
 * */
function createCustomerJourneyPlan(params) {
  return Vue.prototype.$axios.post(Api.customerJourneyPlan, params)
}

/**
 * 删除客户行程
 * */
function deleteCustomerJourneyPlan(id) {
  return Vue.prototype.$axios.delete(`${Api.customerJourneyPlan}/${id}`)
}

/**
 * 客户私转公
 * */
function customerPrivateTransferPublic(params) {
  return Vue.prototype.$axios.post(Api.customerPrivateTransferPublic, qs.stringify(params))
}

/**
 * 客户私转私
 * */
function customerPrivateTransferPrivate(params) {
  return Vue.prototype.$axios.post(Api.customerPrivateTransferPrivate, qs.stringify(params))
}

/**
 * 客户公转私
 * */
function customerPublicTransferPrivate(params) {
  return Vue.prototype.$axios.post(Api.customerPublicTransferPrivate, qs.stringify(params))
}

/**
 * 客户公转公
 * */
function customerPublicTransferPublic(params) {
  return Vue.prototype.$axios.post(Api.customerPublicTransferPublic, qs.stringify(params))
}


/**
 * 客户联系方式校验
 * */
function customerContactWayVerify(params) {
  return Vue.prototype.$axios.get(Api.customerContactWayVerify, {params})
}


const customerService = {
  getCustomerList,
  createOrUpdateCustomer,
  getCustomerDetail,
  getCustomerEventList,
  createShareCustomer,
  deleteShareCustomer,
  //
  createCustomerRevisit,
  deleteCustomerRevisit,
  createCustomerGuideVisit,
  deleteCustomerGuideVisit,
  createCustomerJourneyPlan,
  deleteCustomerJourneyPlan,
  //
  customerPrivateTransferPublic,
  customerPrivateTransferPrivate,
  customerPublicTransferPrivate,
  customerPublicTransferPublic,
  //
  customerContactWayVerify,
}
export default customerService
