import Vue from 'vue'
import Api from './api';

/**
 * 登录
 * */
async function login(params) {
  let result = null
  await Vue.prototype.$axios.post(Api.login, params).then((res)=> {
    if (res.status === 200) {
      const token = res.headers['x-auth-token']
      result = token
    }
  })
  return result
}


/**
 * 退出登录
 * */
function logout(params) {
  return Vue.prototype.$axios.post(Api.logout, params)
}


/**
 * 获取文件域名
 * */
function getFileDomain(params) {
  return Vue.prototype.$axios.get(Api.getFileDomain, {params})
}

/**
 * 上传文件
 * */
function uploadFile(params, config) {
  return Vue.prototype.$axios.post(Api.uploadFile, params, config)
}

/**
 * 字段列表
 * */
function getFieldList(params) {
  return Vue.prototype.$axios.get(Api.fieldList, {params})
}


/**
 * 申请授权码
 * */
function applyAuthCode(params, config) {
  return Vue.prototype.$axios.post(Api.applyAuthCode, params, config)
}

/**
 * 查询授权信息
 * */
function getAuthDetail(applyId, config) {
  return Vue.prototype.$axios.get(`${Api.authDetail}/${applyId}`, config)
}


/**
 * 当前账号信息
 * */
function getCurrentUserInfo(params) {
  return Vue.prototype.$axios.get(Api.currentUserInfo, params)
}

/**
 * 当前用户权限列表
 * */
function getUserPermissionList(params) {
  return Vue.prototype.$axios.get(Api.userPermissionList, params)
}





const globalService = {
  login,
  logout,
  getFileDomain,
  uploadFile,
  getFieldList,
  //
  applyAuthCode,
  getAuthDetail,
  //
  getCurrentUserInfo,
  getUserPermissionList,
}
export default globalService
