/**
 * 正则对象
* */

/**
 正则表达式：^[1][3-8]\d{9}$|^([6|9])\d{7}$|^[0][9]\d{8}$|^6\d{5}$
 规则说明：
 中国大陆：开头1 3-8号段，后边跟9位数字
 台湾：09开头后面跟8位数字
 香港：9或6开头后面跟7位数字
 澳门：66或68开头后面跟5位数字
 * */

/**
 * 国内手机
 * 手机位数是11位
 * */
export const mobilePhoneReg = new RegExp('^1[123456789]\\d{9}$')

/**
 * 国内电话（国内座机）
 * 区号3到4位，可以没有区号，区号和电话之间可以有-隔开，电话位数为8位。
* */
export const telephoneReg = new RegExp('^([0-9]{3,4})?(-)?[0-9]{7,8}$')

/**
 * 港澳台电话（港澳台座机）
 * 香港：9或6开头后面跟7位数字
 * 台湾：09开头后面跟8位数字
 * 澳门：66或68开头后面跟5位数字
 * */
export const HMTMobileReg = new RegExp('^(852)?(-)?([6|9])\\d{7}$|^[0][9]\\d{8}$|^[6]([8|6])\\d{5}$')

/**
 * 国外电话号码。
 * 国外号码数字位数限制在10到20位
* */
export const foreignPhoneReg = new RegExp('^[\\d+]{10,20}$')



/**
 * 图片（根据后缀判断是否是图片）
 * */
export const imageReg = new RegExp('^.+\\.(png|PNG|jpg|JPG|jpeg|JPEG|gif|GIF|webp|WEBP)$')













/**
 * 校验函数
* */

/**
 * 校验国内手机
 * */
export function isMobilePhone(str) {
  return mobilePhoneReg.test(str)
}

/**
* 校验国内电话
* */
export function isTelephone(str) {
  return telephoneReg.test(str)
}


/**
 * 校验港澳台手机
 * */
export function isHMTMobile(str) {
  return HMTMobileReg.test(str)
}

/**
 * 校验国外号码
 * */
export function isForeignPhone(str) {
  return foreignPhoneReg.test(str)
}

/**
 * 校验数字。
 * 数字、数字字符串都属于数字
* */
export function isNumber(val) {
  const regPos = /^\d+(\.\d+)?$/ //非负浮点数
  const regNeg = /^(-(([0-9]+\.[0-9]*[1-9][0-9]*)|([0-9]*[1-9][0-9]*\.[0-9]+)|([0-9]*[1-9][0-9]*)))$/ //负浮点数
  if (regPos.test(val) || regNeg.test(val)) {
    return true
  } else {
    return false
  }
}


/**
 * 校验图片
 * */
export function isImage(str) {
  return imageReg.test(str)
}














/**
 * 替换函数
* */

/**
 * 字符串中间8位替换为*（星号）, 字符串至少15位以上。
 * */
export function replaceMiddleToStar(str) {
  const reg = /(.{3}).{8}(.{4})/i
  const newStr = str.replace(reg, '$1********$2')
  return newStr
}









