import qs from 'qs'
import axios from 'axios'
import { Dialog } from 'vant'
import API from 'src/scripts/service/api'
import { checkFileType, getFileIcon } from 'scripts/utils/file-type'

// toBlob Polyfill
if (!HTMLCanvasElement.prototype.toBlob) {
  Object.defineProperty(HTMLCanvasElement.prototype, 'toBlob', {
    value(callback, type, quality) {
      const binStr = atob(this.toDataURL(type, quality).split(',')[1])
      const len = binStr.length
      const arr = new Uint8Array(len)

      for (let i = 0; i < len; i++) {
        arr[i] = binStr.charCodeAt(i)
      }
      callback(new Blob([arr], {type: type || 'image/png'}))
    }
  })
}




const Uploader = {
  reloadTimes: 0,
  async init({ file = [], maxWidth = 1200, maxHeight = 1200, quality = 0.8 }) {
    const result = []

    return new Promise((resolve, reject)=> {
      const start = async ()=> {
        if (!file.length) {
          resolve(result)
          return
        }

        let currentFile = file.shift()
        if (quality < 0) quality = 0
        if (quality >= 1) quality = 0

        // 如果开启图片上传压缩，则图片类型文件会压缩后上传
        if (quality && checkFileType(currentFile, 'image')) {
          await this.compress(currentFile, maxWidth, maxHeight, quality).then((res)=> {
            currentFile = res
          }).catch((e)=> {
            Dialog({ message: `图片压缩失败:${JSON.stringify(e)}` })
          })
        }

        await this.upload(currentFile).then((res)=> {
          result.push(res)
        }).catch((e)=> {
          Dialog({ message: `上传失败:${JSON.stringify(e)}` })
          result.push(null)
        })
        start()
      }
      start()
    })
  },
  upload(file) {
  	return new Promise((resolve, reject)=> {
      const formData = new FormData()
      formData.append('file', file)
      axios.post(API.uploadFile, formData).then((res)=> {
        if (res.data.code === 200) {
        	resolve(res.data.data)
        } else {
          reject(res.data)
        }
      }).catch(e=> reject(e))
  	})
  },
  getPlusFileObj(url, success, error) {
    plus.io.resolveLocalFileSystemURL(url, (res)=> {
      const fileReader = new plus.io.FileReader()
      fileReader.readAsDataURL(res)
      fileReader.onloadend = success
    }, error)
  },
  compress(file, maxWidth, maxHeight, quality) {
    return new Promise((resolve, reject)=> {
      try {
        console.log('before compress file size:', file.size, ', compress quality:', quality)
        const image = new Image()
        const canvas = document.createElement('canvas')
        const ctx = canvas.getContext('2d')

        this.getPlusFileObj(file, (e)=> {
          image.src = e.target.result
        })
        image.onload = (e)=> {
          let width = image.width
          let height = image.height
          const limit = Math.max(width / maxWidth, height / maxHeight)
          if (limit > 1) {
            width /= limit
            height /= limit
          }
          canvas.width = width
          canvas.height = height
          ctx.fillStyle = '#ffffff'
          ctx.fillRect(0, 0, width, height)
          ctx.drawImage(image, 0, 0, width, height)
          canvas.toBlob((blob)=> {
            console.log('after compress file size:', blob.size)
            resolve(blob)
          }, 'image/jpeg', quality)
        }
      } catch (e) {
        Dialog({ message: `compress catch error:${e}` })
        // window.alert(`compress catch error:${e}`)
      }
    })
  },
}


export default Uploader
