import customerService from 'src/scripts/service/customer'
import store from './index'
import storeModuleName from './storeModuleName'


//
const actionTypes = {
  loadCustomerDetail: 'loadCustomerDetail',
  customerDetail: 'customerDetail',
  customerId: 'customerId',
  //
  isEditCustomer: 'isEditCustomer',
  isSubmitCustomer: 'isSubmitCustomer',
}
const mutationTypes = {
  customerDetail: 'customerDetail',
  customerId: 'customerId',
  //
  isEditCustomer: 'isEditCustomer',
  isSubmitCustomer: 'isSubmitCustomer',
}





/**
 * state
 * */
const state = {
  // 客户详情
  customerDetail: {},
  // 客户di
  customerId: null,

  /**
   * 客户操作
  * */
  // 是否编辑客户
  isEditCustomer: false,
  // 是否提交客户
  isSubmitCustomer: false,
}




/**
 * getters
 * */
const getters = {
  customerDetail: state=> state.customerDetail,
  customerId: state=> state.customerId,
  //
  isEditCustomer: state=> state.isEditCustomer,
  isSubmitCustomer: state=> state.isSubmitCustomer,
}




/**
* actions
* */
const actions = {
  async [actionTypes.loadCustomerDetail] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await customerService.getCustomerDetail(payload)
      .then(async (res)=> {
        if (res.data.code === 200) {
          const Data = res.data.data
          await commit(mutationTypes.customerDetail, Data)
          await commit(mutationTypes.customerId, Data.id)
        }
      })
      .catch((e)=> {
      })
  },
  async [actionTypes.customerDetail] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await commit(mutationTypes.customerDetail, payload)
  },
  async [actionTypes.customerId] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await commit(mutationTypes.customerId, payload)
  },
  //
  async [actionTypes.isEditCustomer] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await commit(mutationTypes.isEditCustomer, payload)
  },
  async [actionTypes.isSubmitCustomer] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await commit(mutationTypes.isSubmitCustomer, payload)
  },
}



/**
 * mutations
 * */
const mutations = {
  [mutationTypes.customerDetail](state, payload) {
    state.customerDetail = payload
  },
  [mutationTypes.customerId](state, payload) {
    state.customerId = payload
  },
  //
  [mutationTypes.isEditCustomer](state, payload) {
    state.isEditCustomer = payload
  },
  [mutationTypes.isSubmitCustomer](state, payload) {
    state.isSubmitCustomer = payload
  },
}










/**
 * dispatch action
* */
// 加载客户详情
async function loadCustomerDetail(payload) {
  let result = null
  await store.dispatch(`${storeModuleName.customer}/${actionTypes.loadCustomerDetail}`, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}

// 更新客户详情
async function updateCustomerDetail(payload) {
  let result = null
  await store.dispatch(`${storeModuleName.customer}/${actionTypes.customerDetail}`, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}

// 更新客户id
async function updateCustomerId(payload) {
  let result = null
  await store.dispatch(`${storeModuleName.customer}/${actionTypes.customerId}`, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}

// 更新是否编辑客户
async function updateIsEditCustomer(payload) {
  let result = null
  await store.dispatch(`${storeModuleName.customer}/${actionTypes.isEditCustomer}`, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}

// 更新是否提交客户
async function updateIsSubmitCustomer(payload) {
  let result = null
  await store.dispatch(`${storeModuleName.customer}/${actionTypes.isSubmitCustomer}`, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}






export const dispatchCustomerAction = {
  loadCustomerDetail,
  updateCustomerDetail,
  updateCustomerId,
  //
  updateIsEditCustomer,
  updateIsSubmitCustomer,
}
export default {
  namespaced: true,
  modules: {
  },
  state,
  getters,
  actions,
  mutations,
}
