import globalService from 'src/scripts/service/global'
import store from './index'
import storeModuleName from './storeModuleName'
//
const actionTypes = {
  restoreGlobalState: 'restoreGlobalState',
  loadFileDomain: 'loadFileDomain',
  fileDomain: 'fileDomain',
  loadFieldConfig: 'loadFieldConfig',
  fieldConfig: 'fieldConfig',
  //
  loadUserInfo: 'loadUserInfo',
  userInfo: 'userInfo',
  permissionList: 'permissionList',
  loadPermissionList: 'loadPermissionList',
}
const mutationTypes = {
  restoreGlobalState: 'restoreGlobalState',
  fileDomain: 'fileDomain',
  fieldConfig: 'fieldConfig',
  userInfo: 'userInfo',
  permissionList: 'permissionList',
}





/**
 * state
 * */
const state = {
  userInfo: {},
  permissionList: [],
  fileDomain: null,
  fieldConfig: {},
}




/**
 * getters
 * */
const getters = {
  fileDomain: state=> state.fileDomain,
  fieldConfig: state=> state.fieldConfig,
  userInfo: state=> state.userInfo,
  permissionList: state=> state.permissionList,
}




/**
* actions
* */
const actions = {
  async [actionTypes.restoreGlobalState] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await commit(mutationTypes.restoreGlobalState, payload)
  },
  async [actionTypes.loadFileDomain] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await globalService.getFileDomain()
      .then(async (res)=> {
        if (res.data.code === 200) {
          await commit(mutationTypes.fileDomain, `http://${res.data.data}/`)
        }
      })
  },
  async [actionTypes.fileDomain] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await commit(mutationTypes.fileDomain, payload)
  },
  async [actionTypes.loadFieldConfig] ({ commit, state, dispatch, getters, rootState, rootGetters }, groupCodes) {
    const params = {
      sort: 'weight,asc',
      status: 'ACTIVE',
      page: 0,
      size: 999,
      group_codes: groupCodes,
    }
    await globalService.getFieldList(params)
      .then(async (res)=> {
        if (res.data && res.data.code === 200) {
          const Data = res.data.data
          const obj = {
            module: groupCodes,
            fieldList: Data.content || []
          }
          if (obj.module) {
            await commit(mutationTypes.fieldConfig, obj)
          }
        }
      })
    return JSON.parse(JSON.stringify(state.fieldConfig))
  },
  async [actionTypes.fieldConfig] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await commit(mutationTypes.fieldConfig, payload)
  },
  async [actionTypes.userInfo] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await commit(mutationTypes.userInfo, payload)
  },
  async [actionTypes.loadUserInfo] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await globalService.getCurrentUserInfo()
      .then(async (res)=> {
        if (res.data.code === 200) {
          await commit(mutationTypes.userInfo, res.data.data)
        }
      })
  },
  async [actionTypes.permissionList] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await commit(mutationTypes.permissionList, payload)
  },
  async [actionTypes.loadPermissionList] ({ commit, state, dispatch, getters, rootState, rootGetters }, payload) {
    await globalService.getUserPermissionList()
      .then(async (res)=> {
        if (res.data.code === 200) {
          await commit(mutationTypes.permissionList, res.data.data)
        }
      })
  },
}



/**
 * mutations
 * */
const mutations = {
  [mutationTypes.fileDomain](state, payload) {
    state.fileDomain = payload
  },
  [mutationTypes.fieldConfig](state, payload) {
    const { module, fieldList } = payload
    state.fieldConfig[module] = fieldList
  },
  [mutationTypes.restoreGlobalState](state, payload) {
    Object.assign(state, payload)
  },
  [mutationTypes.userInfo](state, payload) {
    state.userInfo = payload
  },
  [mutationTypes.permissionList](state, payload) {
    state.permissionList = payload
  },
}










/**
 * dispatch action
* */
// 恢复状态
async function restoreGlobalState(payload) {
  let result = null
  await store.dispatch(actionTypes.restoreGlobalState, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}

// 加载文件域名
async function loadFileDomain(payload) {
  let result = null
  await store.dispatch(actionTypes.loadFileDomain, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}
// 更新文件域名
async function updateFileDomain(payload) {
  let result = null
  await store.dispatch(actionTypes.fileDomain, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}
// 加载字段配置
async function loadFieldConfig(payload) {
  let result = null
  await store.dispatch(actionTypes.loadFieldConfig, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}
// 更新字段配置
async function updateFieldConfig(payload) {
  let result = null
  await store.dispatch(actionTypes.fieldConfig, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}


// 更新用户信息
async function updateUserInfo(payload) {
  let result = null
  await store.dispatch(actionTypes.userInfo, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}

// 加载用户信息
async function loadUserInfo(payload) {
  let result = null
  await store.dispatch(actionTypes.loadUserInfo, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}


// 更新用户权限列表
async function updatePermissionList(payload) {
  let result = null
  await store.dispatch(actionTypes.permissionList, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}

// 加载用户权限列表
async function loadPermissionList(payload) {
  let result = null
  await store.dispatch(actionTypes.loadPermissionList, payload)
    .then((res)=> {
      result = res
    })
  return new Promise((resolve, reject)=> {
    resolve(result)
  })
}






export const dispatchGlobalAction = {
  loadFileDomain,
  updateFileDomain,
  loadFieldConfig,
  updateFieldConfig,
  restoreGlobalState,
  //
  updateUserInfo,
  loadUserInfo,
  updatePermissionList,
  loadPermissionList,
}
export default {
  modules: {
  },
  state,
  getters,
  actions,
  mutations,
}
